//
//  FractionPickerViewController.m
//  FractionPicker
//
//  Created by Terry Payne on 10/06/2011.
//  Copyright 2011 University of Liverpool. All rights reserved.
//

#import "FractionPickerViewController.h"

@implementation FractionPickerViewController

@synthesize fraction1PickerView;
@synthesize fraction2PickerView;
@synthesize fractionLabel;
@synthesize showFractionButton;

- (IBAction)fractionButtonPressed:(id)sender{

    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Add Fractions"
                                                    message:@"You have to modify the fractionButtonPressed yourself!"
                                                   delegate:self cancelButtonTitle:@"Done" otherButtonTitles: nil];
    [alert show];
    [alert release];
}


// ======================================================================
#pragma mark - UIPickerViewDelegate methods
// ======================================================================


- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component
{
    // Don't care which component changed value.
    // Just update the presentation of the fraction in terms of numerator and denominator
    // As the range is 1-MAX_NUMBER_ON_PICKER, we add 1 to the row
    
    NSInteger myNumerator = 1+[pickerView selectedRowInComponent:NUMERATOR];
    NSInteger myDenominator = 1+[pickerView selectedRowInComponent:DENOMINATOR];
    
    // This could be written more elegantly
    if (pickerView == fraction1PickerView) {
        // Fraction 1 picker called this method
        numerator1 = myNumerator;
        denominator1 = myDenominator;
    } else {
        // Fraction 2 picker called this method
        numerator2 = myNumerator;
        denominator2 = myDenominator;
    }
    
    [self updateFractionLabel];
}

- (void)updateFractionLabel {
    NSString *fractionStr = [NSString stringWithFormat:@"%d/%d + %d/%d = ???",
                             numerator1, denominator1, numerator2, denominator2];
    
    [fractionLabel setText:fractionStr];
}

- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component
{
    // Both pickers just display numbers from 1 to 9
    return [NSString stringWithFormat:@"%d", 1+row];
}

// ======================================================================
#pragma mark - UIPickerViewDataSource methods
// ======================================================================

// Returns the number of components (or “columns”) that the picker view should display.
- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView
{
    // Ignore the value of pickerView, as we assume only one picker for now
    return NUMBER_OF_PICKER_COMPONENTS;
}

// Returns the number of rows for the component.
- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component
{
    // Ignore the value of pickerView, as we assume only one picker for now
    return MAX_NUMBER_ON_PICKER;
}

// ======================================================================
#pragma mark - UIPicker Other Methods
// ======================================================================



// ======================================================================
#pragma mark - Memory Management
// ======================================================================

- (void)dealloc
{
    [super dealloc];
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

// ======================================================================
#pragma mark - View lifecycle
// ======================================================================


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad
{
    [super viewDidLoad];

    numerator1 = numerator2 = denominator1 = denominator2 = 1;
    [self updateFractionLabel];
}


- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end
